<?php

namespace Kylin\AntiAddiction\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * @see \Kylin\AntiAddiction\Services\AntiAddictionService
 */
class KylinAntiAddiction extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-anti-addiction';
    }
}
