<?php

namespace Kylin\AntiAddiction\Exceptions;

use Kylin\AntiAddiction\Enums\AntiAddictionErrorCode;
use Kylin\Core\Exceptions\BusinessException;

/**
 * 防沉迷异常
 */
class AntiAddictionException extends BusinessException
{
    public function __construct(
        AntiAddictionErrorCode $errorCode,
        ?string $message = null,
    ) {
        parent::__construct($errorCode, $message);
    }
}
